@@ -70,12 +70,20 @@ class AdReports(Stream):
 
     def generate_daily_date_windows(self):
         bookmark = singer.bookmarks.get_bookmark(self.state, self.stream_name, self.replication_keys[0])
-        report_date = utils.strptime_to_utc(bookmark or self.config['start_date'])
+        lookback_window = datetime.timedelta(days=int(self.config.get('lookback_window') or 7))
+        report_date = min(utils.strptime_to_utc(bookmark or self.config['start_date']),
+                          utils.now() - lookback_window)
 
         end_date = utils.now()
         if self.config.get('end_date'):
             end_date = utils.strptime_to_utc(self.config.get('end_date'))
 
+        if report_date > end_date:
+            LOGGER.warning("Calculated report_date %s is greater than end_date %s; no reports will be retrieved.",
+                           datetime.datetime.strftime(report_date, "%Y-%m-%d"),
+                           datetime.datetime.strftime(end_date, "%Y-%m-%d")
+                           )
+
         while report_date <= end_date:
             yield report_date
             report_date += datetime.timedelta(days=1)
@@ -95,7 +103,7 @@ class AdReports(Stream):
                     'end_date': request_date,
                 })
                 for rec in records.get('results'):
-                    rec['date'] = utils.strftime(report_date)
+                    rec['date'] = datetime.datetime.strftime(report_date, "%Y-%m-%dT00:00:00.000000Z")
                     yield rec
 
             # Write bookmark after syncing all Advertisables for the day
